Module nodes

Module nodes 

DCS Nodes module

Nodes are either sensor nodes that read data and coordinate it, and actuator nodes that receive commands from sensor nodes.

Modules

actuator
sensor
translator
utils

Structs

SystemClusterId
SystemMetadata
Metadata associated to the node at the system level.
SystemNodeId
Universal id used throughout the system

Enums

NodeRole
The nodes of a system are either sensors or actuators.

Traits

CommunicationSDK
This sdk comrises of all the types that must be defined for the communication of the system to work. For example if tcp/ip should be used instead of bluetooth these are the requirements that should be fulfilled
CoordinationSDK
This sdk comrises of all the types that must be defined for the coordination of the system to work. For example if a coordination algorithm such as paxos were to be implemented these interfaces must be implemented as well.
SerializationSDK
This sdk contains all the information to serialize all of the system’s messages.