Module properties

Module properties 

DCS Properties

Here lives a number of properties relevant to the system.

Structs

EncodedMetadata

Enums

SystemError

Constants

ADDRESSES_MAX_SIZE
Max length in bytes of the serialized addresses. Used mainly in the crate::membership::client::MembershipMessage
CLUSTERS_PER_TRANSLATOR
Number of max clusters where a translator can be.
CLUSTER_NODE_COUNT
Number of max nodes allowed in a cluster
DESCRIPTIVE_LOG_ERROR_MAX_SIZE
Max buffer size for errors being logged.
MAX_NODE_COUNT
Number of max nodes allowed in the system.
MAX_QUEUED_MESSAGES
Max ammount of messages to be saved by the crate::communication::service::GenericCommunicationService.
MEASUREMENTS_MAX_COUNT
Max ammount of measurements per each node to be hold in the crate::rules::measurements::SystemState
MESSAGE_BUFFER_MAX_SIZE
Max buffer size to be used when encoding and decoding messages.
METADATA_MAX_SIZE
Max metadata to be exchanged by the crate::communication::messages::ControlMessage
RULES_AMOUNT
Max ammount of rules to be stored in the crate::rules::manager::RulesPool.

Functions

init_buffer
init_system_vec

Type Aliases

AddressesBytesVec
EncodedMetadataVec
MeasurementsVec
SystemBufferVec