RuleStrategyOperators

Struct RuleStrategyOperators 

pub struct RuleStrategyOperators;
RulesOperator provides some basic operations for the rule enging, such as utility calculating a key value from a set of measurements (mean, max, min) and then applying some control operation as over or below.

Implementations

Source

impl RuleStrategyOperators

pub fn average(measurements: &MeasurementsVec) -> i32

pub fn max(measurements: &MeasurementsVec) -> Option<i32>

pub fn min(measurements: &MeasurementsVec) -> Option<i32>

pub fn over(control: i32, value: i32) -> bool

pub fn below(control: i32, value: i32) -> bool