DCS Properties
Here lives a number of properties relevant to the system.
Structs
Enums
Constants
- ADDRESSES_
MAX_ SIZE - Max length in bytes of the serialized addresses. Used mainly in the
crate::membership::client::MembershipMessage - CLUSTERS_
PER_ TRANSLATOR - Number of max clusters where a translator can be.
- CLUSTER_
NODE_ COUNT - Number of max nodes allowed in a cluster
- DESCRIPTIVE_
LOG_ ERROR_ MAX_ SIZE - Max buffer size for errors being logged.
- MAX_
NODE_ COUNT - Number of max nodes allowed in the system.
- MAX_
QUEUED_ MESSAGES - Max ammount of messages to be saved by the
crate::communication::service::GenericCommunicationService. - MEASUREMENTS_
MAX_ COUNT - Max ammount of measurements per each node to be hold in the
crate::rules::measurements::SystemState - MESSAGE_
BUFFER_ MAX_ SIZE - Max buffer size to be used when encoding and decoding messages.
- METADATA_
MAX_ SIZE - Max metadata to be exchanged by the
crate::communication::messages::ControlMessage - RULES_
AMOUNT - Max ammount of rules to be stored in the
crate::rules::manager::RulesPool.