pub struct RuleStrategyOperators;Expand description
RulesOperator provides some basic operations for the rule enging, such as utility calculating a key value from a set of measurements (mean, max, min) and then applying some control operation as over or below.
Implementations